function [salida acc]=main(data,cova,nclus,burn,reps,thin)

% salida will contain the mcmc output and acc will display the accepatnace rates.  data should be a
% T by m matrix; nclus is the number of clusters; burn is the burn-in period; reps is the total
% number of repetitions; and thin is the thinning factor.

%______________________________________________________________________________________
    nvar=size(data,2);
    ncov=size(cova,1);
    ilevs=nanmean(data); 
    %Calculates the parameter for the prior in tau
    sbet=std(ilevs,1)^2/2;
%______________________________________________________________________________________
    %Init output
    outlen=(reps-burn)/thin;
    salida.al=NaN(outlen,nclus);       acc.al=zeros(1,nclus);
    salida.be=NaN(outlen,nvar);        acc.be=zeros(1,nvar);
    salida.ga=NaN(outlen,1);           acc.ga=0;
    salida.la=NaN(outlen,1);       
    salida.df=NaN(outlen,1);           acc.df=0;
    salida.aal=NaN(outlen,nclus);      
    acc.aal=zeros(1,nclus);
    salida.bal=NaN(outlen,nclus);      
    acc.bal=zeros(1,nclus);
    salida.hb=NaN(outlen,nclus);
    salida.ht=NaN(outlen,1);
    salida.ab=NaN(outlen,1);           acc.ab=0;
    salida.Zij=zeros(nvar,nclus);
    salida.eta=NaN(outlen,nclus);
    salida.mu=NaN(outlen,nclus,ncov);  acc.mu=zeros(1,ncov);
    salida.covmu=NaN(outlen,ncov);     acc.cvm=zeros(1,ncov);
    nin=0;

%______________________________________________________________________________________
 %______________________________________________________________________________________
    %Init chains
    al=zeros(1,nclus);         
    be=0.0*ones(1,nvar);         
    mu=zeros(2,nclus,ncov);   
    ga=1;                     
    la=1000;                   
    df=30;                      
    aal=15*ones(1,nclus);        
    bal=15*ones(1,nclus);      
    hbe=zeros(1,nclus);
    hta=1000;
    hab=0.70;                   
 %______________________________________________________________________________________
    aca=zeros(1,nclus);
    acb=zeros(1,nvar);
    acm=zeros(1,nclus);
    acg=0;
    acn=0;
    acaa=zeros(1,nclus);
    acba=zeros(1,nclus);
    acab=0;
    comu=0*ones(1,ncov);        
    acvm=zeros(1,ncov);
 %______________________________________________________________________________________

    %Init clustering
    Zij=ones(nvar,nclus)/nclus;

 %______________________________________________________________________________________
    %Proposal's parameters
    tb=7e2;    %scale parameter for betas
    tm=1e4*[14 6 4 ];   %scale parameter for coeffs
    ppaa=[245 140 150 ]; %scale parameter for alpha
    ppag=250; %scale parameter for gamma
    ppan=130; %scale parameter for degrees of freedom
    ppaal=[2.5 2.5 2.5 ];%2.5*ones(1,nclus); %scale parameter for alpha hyperparameter a
    ppbal=[2.5 2.5 2.5 ];%2.5*ones(1,nclus); %scale parameter for alpha hyperparameter b
    ppab=1.01;
    baas=1.01;
%______________________________________________________________________________________
%______________________________________________________________________________________
    %Hyperparameters
    arr=2; qaq=0.1;
    csq=0.05^2; cm=0.05;
    mcoef=zeros(nclus,ncov);
    csa=1;
%______________________________________________________________________________________
tic
    for i=1:reps
        cator=               nind(Zij);
        ome=                 mix(data,cova,cator,al,be,mu,ga,la,df);
        la=                  nlam(data,cova,cator,al,be,mu,ga,la,ome);
        [be acb]=            nbe(data,cova,cator,al,be,mu,ga,la,ome,hbe,hta,tb,acb);
        [al aca]=            new_dynamics(data,cova,cator,al,be,mu,ga,la,ome,aal,bal,ppaa,aca);
        [mu acm]=            new_coeff(data,cova,cator,al,be,mu,ga,la,ome,mcoef,csa,comu,tm,acm);
        if nclus==1
            comu=0; acvm=1;
        else
            [comu acvm] =        naas(mu,comu,csa,mcoef,baas,acvm);
        end
        [ga acg]=            nga(data,cova,cator,al,be,mu,ga,la,ome,ppag,acg);
        [df acn]=            ndf(data,df,ome,ppan,acn);
        [aal bal acaa acba]= new_hypal(al,aal,bal,ppaal,ppbal,arr,qaq, acaa, acba);
        [hbe hta hab acab]=  newhyp(be,cator,hbe,hta,sbet,cm,csq,hab,ppab,acab);
        epr=                 0.5*ones(1,nclus) + 2*sum(cator);
        eta=                 rdiri(epr);
        Zij=               prupdate(data,cova,al,be,mu,ga,la,df,eta);
%______________________________________________________________________________________
% Comment out accordingly.  In first instance, run with permsamp commented out and then try to find
% an identifying constraint.  Identify sorts the output according to alpha, beta or mu.

        [al hbe aal bal mu]=  persam(al,hbe,aal,bal,mu);
        [al hbe aal bal mu]=  identify(al,hbe,aal,bal,mu,ncov,1); %1=alpha; 2=beta; 3=mu
%______________________________________________________________________________________

        if i==burn
            disp('Burn-in phase completed')
        end
%______________________________________________________________________________________
%Collection        
        if i>burn && mod(i,thin)==0
            nin=nin+1;
            rua=size(al,1);
            salida.al(nin,:)=al(rua,:);
            
            salida.mu(nin,:,:)=squeeze(mu(2,:,:));
            salida.covmu(nin,:)=comu(size(comu,1),:);

            salida.ga(nin)=ga(length(ga));
            salida.la(nin)=la(length(la));
            salida.df(nin)=df(length(df));
            
            rua=size(aal,1); 
            salida.aal(nin,:)=aal(rua,:);

            rua=size(bal,1); 
            salida.bal(nin,:)=bal(rua,:);
            
            rub=size(be,1);
            salida.be(nin,:)=be(rub,:);
            
            rub=size(hbe,1);
            salida.hb(nin,:)=hbe(rub,:);
            
            salida.eta(nin,:)=eta;
            
            salida.ht(nin)=hta(length(hta));
            salida.ab(nin)=hab(length(hab));
            salida.Zij=salida.Zij+cator;
        end
%______________________________________________________________________________________
         if i>burn && mod((i-burn),(reps-burn)/10)==0
             disp([num2str((i-burn)/(reps-burn)*100) '% done'])
         elseif i<burn && mod(i,burn/4)==0
             disp([num2str((i/burn)*100) '% of burn-in'])
         
         end
   end
%______________________________________________________________________________________
toc
    
    acc.al=aca/reps;
    acc.mu=acm/reps;
    acc.ga=acg/reps;
    acc.df=acn/reps;
    acc.aal=acaa/reps;
    acc.bal=acba/reps;
    acc.be=acb/reps;
    acc.ab=acab/reps;
    acc.cvm=acvm/reps;
    
    salida.Zij=salida.Zij/((reps-burn)/thin);
    salida.sbet=sbet;
    
%______________________________________________________________________________________

    disp('Acceptance rates for alpha')
    disp(acc.al )
    disp('Acceptance rates for coefficients')
    disp(acc.mu )
    disp('Acc rates for aal')
    disp(acc.aal)
    disp('Acc rates for bal')
    disp(acc.bal)
    disp('Acc rates for ga nu and hya')
    disp([acc.ga acc.df acc.ab])
    disp('rates for covs')
    disp([acc.cvm])
    disp('Acc rates for beta')
    disp([min(acc.be) max(acc.be)])
    disp('Relative size')
    disp([mean(salida.Zij); mean(salida.eta)])